@@ -1,5 +1,7 @@
 module Sexp = Sexp
 module Sexp_conv = Sexp_conv
 module Sexp_conv_error = Sexp_conv_error
+module Sexp_conv_record = Sexp_conv_record
+module Sexp_conv_labeled_tuple = Sexp_conv_labeled_tuple
 module Sexp_grammar = Sexp_grammar
 module Sexpable = Sexpable
